#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const ws_1 = __importDefault(require("ws"));
const commander_1 = require("commander");
const promptly_1 = __importDefault(require("promptly"));
const ansi_colors_1 = __importDefault(require("ansi-colors"));
const tslog_1 = require("tslog");
const const_1 = require("../lib/const");
const command_1 = require("../lib/driver/command");
const command_2 = require("../lib/device/command");
const command_3 = require("../lib/station/command");
const cmdHelp = (cmd) => {
    switch (cmd) {
        case command_1.DriverCommand.setVerifyCode:
            console.log(`${cmd} <numeric_code>`);
            break;
        case command_1.DriverCommand.setCaptcha:
            console.log(`${cmd} <captcha> [<id>]`);
            break;
        case command_1.DriverCommand.pollRefresh:
        case command_1.DriverCommand.isConnected:
        case command_1.DriverCommand.isPushConnected:
        case command_1.DriverCommand.connect:
        case command_1.DriverCommand.disconnect:
        case command_1.DriverCommand.getVideoEvents:
        case command_1.DriverCommand.getAlarmEvents:
        case command_1.DriverCommand.getHistoryEvents:
        case command_1.DriverCommand.getLogLevel:
        case command_1.DriverCommand.startListeningLogs:
        case command_1.DriverCommand.stopListeningLogs:
            console.log(`${cmd}`);
            break;
        case command_1.DriverCommand.setLogLevel:
            console.log(`${cmd} <loglevel>`);
            break;
        case command_2.DeviceCommand.setStatusLed:
        case command_2.DeviceCommand.setAutoNightVision:
        case command_2.DeviceCommand.setMotionDetection:
        case command_2.DeviceCommand.setSoundDetection:
        case command_2.DeviceCommand.setPetDetection:
        case command_2.DeviceCommand.setRTSPStream:
        case command_2.DeviceCommand.setAntiTheftDetection:
        case command_2.DeviceCommand.enableDevice:
        case command_2.DeviceCommand.lockDevice:
            console.log(`${cmd} <device_sn> <true|false>`);
            break;
        case command_2.DeviceCommand.setWatermark:
            console.log(`${cmd} <device_sn> <numeric_option>`);
            break;
        case command_2.DeviceCommand.getPropertiesMetadata:
        case command_2.DeviceCommand.getProperties:
        case command_2.DeviceCommand.startLivestream:
        case command_2.DeviceCommand.stopLivestream:
        case command_2.DeviceCommand.resetAlarm:
        case command_2.DeviceCommand.getVoices:
        case command_2.DeviceCommand.cancelDownload:
        case command_2.DeviceCommand.isLiveStreaming:
        case command_2.DeviceCommand.getCommands:
        case command_2.DeviceCommand.startRTSPLivestream:
        case command_2.DeviceCommand.stopRTSPLivestream:
        case command_2.DeviceCommand.isRTSPLiveStreaming:
        case command_2.DeviceCommand.calibrateLock:
            console.log(`${cmd} <device_sn>`);
            break;
        case command_2.DeviceCommand.setProperty:
            console.log(`${cmd} <device_sn> <name> <value>`);
            break;
        case command_2.DeviceCommand.triggerAlarm:
            console.log(`${cmd} <device_sn> <seconds>`);
            break;
        case command_2.DeviceCommand.panAndTilt:
            console.log(`${cmd} <device_sn> <direction>`);
            break;
        case command_2.DeviceCommand.quickResponse:
            console.log(`${cmd} <device_sn> <voiceId>`);
            break;
        case command_2.DeviceCommand.startDownload:
            console.log(`${cmd} <device_sn> <path> <cipherId>`);
            break;
        case command_2.DeviceCommand.hasProperty:
        case command_2.DeviceCommand.hasCommand:
            console.log(`${cmd} <device_sn> <name>`);
            break;
        case command_3.StationCommand.setGuardMode:
            console.log(`${cmd} <station_sn> <numeric_code>`);
            break;
        case command_3.StationCommand.isConnected:
        case command_3.StationCommand.connect:
        case command_3.StationCommand.disconnect:
        case command_3.StationCommand.resetAlarm:
        case command_3.StationCommand.reboot:
        case command_3.StationCommand.getCommands:
            console.log(`${cmd} <station_sn>`);
            break;
        case command_3.StationCommand.getPropertiesMetadata:
        case command_3.StationCommand.getProperties:
            console.log(`${cmd} <station_sn>`);
            break;
        case command_3.StationCommand.setProperty:
            console.log(`${cmd} <station_sn> <name> <value>`);
            break;
        case command_3.StationCommand.triggerAlarm:
            console.log(`${cmd} <station_sn> <seconds>`);
            break;
        case command_3.StationCommand.hasProperty:
        case command_3.StationCommand.hasCommand:
            console.log(`${cmd} <station_sn> <name>`);
            break;
        /*case StationCommand.getCameraInfo:
        case StationCommand.getStorageInfo:
            console.log("Command not implemented.");
            break;*/
        default:
            console.log(`Type HELP "command name" to display more information about a specific command.`);
            Object.values(command_1.DriverCommand).forEach((cmd) => {
                console.log(cmd);
            });
            Object.values(command_2.DeviceCommand).forEach((cmd) => {
                console.log(cmd);
            });
            Object.values(command_3.StationCommand).forEach((cmd) => {
                console.log(cmd);
            });
            console.log("exit");
            console.log("quit");
            break;
    }
};
const isNumber = (value) => {
    try {
        Number.parseInt(value);
        return true;
    }
    catch (error) {
        return false;
    }
};
const isTrueFalse = (value) => {
    if (value.toLowerCase() === "true" || value.toLowerCase() === "false") {
        return true;
    }
    return false;
};
const program = new commander_1.Command();
program
    .addOption(new commander_1.Option("-s, --schemaVersion <host>", "Schema version the server should support").default(const_1.maxSchemaVersion, "max client supported version"))
    .addOption(new commander_1.Option("-H, --host <host>", "Host to connect to").default("localhost"))
    .addOption(new commander_1.Option("-p, --port <port>", "Port to connect to").default(3000))
    .addOption(new commander_1.Option("-v, --verbose"));
program.parse(process.argv);
const options = program.opts();
const schemaVersion = options.schemaVersion
    ? Number(options.schemaVersion)
    : const_1.maxSchemaVersion;
const url = `ws://${options.host}:${options.port}`;
if (isNaN(schemaVersion) || schemaVersion > const_1.maxSchemaVersion || schemaVersion < 0) {
    console.log("Schema version must be between 0 and ", const_1.maxSchemaVersion);
    process.exit();
}
if (!options.verbose) {
    console.info("Connecting to", url);
}
const logger = new tslog_1.Logger({ minLevel: options.verbose ? "silly" : "info", displayDateTime: false, displayFunctionName: false, displayLogLevel: false, displayFilePath: "hidden" });
const socket = new ws_1.default(url);
socket.on("open", function open() {
    socket.send(JSON.stringify({
        messageId: "api-schema-id",
        command: "set_api_schema",
        schemaVersion: schemaVersion,
    }));
    socket.send(JSON.stringify({
        messageId: "start-listening-result",
        command: "start_listening",
    }));
});
socket.on("message", (data) => {
    const msg = JSON.parse(data.toString());
    /*if (msg.type === "event") {
        const event = msg as OutgoingEventMessage;
        if (event.event.source === "driver" && event.event.event === "verify code") {
            (async () => {
                const verifyCode = await promptly.prompt("Insert verify code: ");
                socket.send(JSON.stringify({
                    messageId: "set_verify_code",
                    command: "driver.set_verify_code",
                    verifyCode: verifyCode
                }));
            })();
        }
    }*/
    if (options.verbose) {
        //console.log(JSON.stringify(msg));
        logger.info("Response:", msg);
    }
    else {
        console.dir(msg);
    }
});
let closing = false;
const handleShutdown = () => {
    // Pressing ctrl+c twice.
    if (closing) {
        process.exit();
    }
    // Close gracefully
    closing = true;
    if (!options.verbose) {
        console.log("Shutting down");
    }
    socket.close();
    process.exit();
};
process.on("SIGINT", handleShutdown);
process.on("SIGTERM", handleShutdown);
(async () => {
    let cmd;
    do {
        cmd = await promptly_1.default.prompt(ansi_colors_1.default.cyan.bold("eufy-security>"));
        const args = cmd.split(" ");
        switch (args[0]) {
            case "help":
                if (args.length <= 1 || args.length > 2) {
                    cmdHelp("");
                }
                else {
                    cmdHelp(args[1]);
                }
                break;
            case command_1.DriverCommand.setVerifyCode:
                if (args.length === 2 && isNumber(args[1])) {
                    socket.send(JSON.stringify({
                        messageId: command_1.DriverCommand.setVerifyCode.split(".")[1],
                        command: command_1.DriverCommand.setVerifyCode,
                        verifyCode: args[1]
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_1.DriverCommand.setCaptcha:
                if (args.length === 2 || args.length === 3) {
                    socket.send(JSON.stringify({
                        messageId: command_1.DriverCommand.setCaptcha.split(".")[1],
                        command: command_1.DriverCommand.setCaptcha,
                        captchaId: args.length === 3 ? args[2] : undefined,
                        captcha: args[1]
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_1.DriverCommand.pollRefresh:
                if (args.length === 1) {
                    socket.send(JSON.stringify({
                        messageId: command_1.DriverCommand.pollRefresh.split(".")[1],
                        command: command_1.DriverCommand.pollRefresh
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_1.DriverCommand.isConnected:
                if (args.length === 1) {
                    socket.send(JSON.stringify({
                        messageId: command_1.DriverCommand.isConnected.split(".")[1],
                        command: command_1.DriverCommand.isConnected
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_1.DriverCommand.isPushConnected:
                if (args.length === 1) {
                    socket.send(JSON.stringify({
                        messageId: command_1.DriverCommand.isPushConnected.split(".")[1],
                        command: command_1.DriverCommand.isPushConnected
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_1.DriverCommand.connect:
                if (args.length === 1) {
                    socket.send(JSON.stringify({
                        messageId: command_1.DriverCommand.connect.split(".")[1],
                        command: command_1.DriverCommand.connect
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_1.DriverCommand.disconnect:
                if (args.length === 1) {
                    socket.send(JSON.stringify({
                        messageId: command_1.DriverCommand.disconnect.split(".")[1],
                        command: command_1.DriverCommand.disconnect
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_1.DriverCommand.getVideoEvents:
                if (args.length === 1) {
                    socket.send(JSON.stringify({
                        messageId: command_1.DriverCommand.getVideoEvents.split(".")[1],
                        command: command_1.DriverCommand.getVideoEvents
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_1.DriverCommand.getAlarmEvents:
                if (args.length === 1) {
                    socket.send(JSON.stringify({
                        messageId: command_1.DriverCommand.getAlarmEvents.split(".")[1],
                        command: command_1.DriverCommand.getAlarmEvents
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_1.DriverCommand.getHistoryEvents:
                if (args.length === 1) {
                    socket.send(JSON.stringify({
                        messageId: command_1.DriverCommand.getHistoryEvents.split(".")[1],
                        command: command_1.DriverCommand.getHistoryEvents
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_1.DriverCommand.getLogLevel:
                if (args.length === 1) {
                    socket.send(JSON.stringify({
                        messageId: command_1.DriverCommand.getLogLevel.split(".")[1],
                        command: command_1.DriverCommand.getLogLevel
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_1.DriverCommand.startListeningLogs:
                if (args.length === 1) {
                    socket.send(JSON.stringify({
                        messageId: command_1.DriverCommand.startListeningLogs.split(".")[1],
                        command: command_1.DriverCommand.startListeningLogs
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_1.DriverCommand.stopListeningLogs:
                if (args.length === 1) {
                    socket.send(JSON.stringify({
                        messageId: command_1.DriverCommand.stopListeningLogs.split(".")[1],
                        command: command_1.DriverCommand.stopListeningLogs
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_1.DriverCommand.setLogLevel:
                if (args.length === 2) {
                    socket.send(JSON.stringify({
                        messageId: command_1.DriverCommand.setLogLevel.split(".")[1],
                        command: command_1.DriverCommand.setLogLevel,
                        level: args[1]
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_2.DeviceCommand.setStatusLed:
                if (args.length === 3 && isTrueFalse(args[2])) {
                    socket.send(JSON.stringify({
                        messageId: command_2.DeviceCommand.setStatusLed.split(".")[1],
                        command: command_2.DeviceCommand.setStatusLed,
                        serialNumber: args[1],
                        value: args[2] === "true" ? true : false,
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_2.DeviceCommand.setAutoNightVision:
                if (args.length === 3 && isTrueFalse(args[2])) {
                    socket.send(JSON.stringify({
                        messageId: command_2.DeviceCommand.setAutoNightVision.split(".")[1],
                        command: command_2.DeviceCommand.setAutoNightVision,
                        serialNumber: args[1],
                        value: args[2] === "true" ? true : false,
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_2.DeviceCommand.setMotionDetection:
                if (args.length === 3 && isTrueFalse(args[2])) {
                    socket.send(JSON.stringify({
                        messageId: command_2.DeviceCommand.setMotionDetection.split(".")[1],
                        command: command_2.DeviceCommand.setMotionDetection,
                        serialNumber: args[1],
                        value: args[2] === "true" ? true : false,
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_2.DeviceCommand.setSoundDetection:
                if (args.length === 3 && isTrueFalse(args[2])) {
                    socket.send(JSON.stringify({
                        messageId: command_2.DeviceCommand.setSoundDetection.split(".")[1],
                        command: command_2.DeviceCommand.setSoundDetection,
                        serialNumber: args[1],
                        value: args[2] === "true" ? true : false,
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_2.DeviceCommand.setPetDetection:
                if (args.length === 3 && isTrueFalse(args[2])) {
                    socket.send(JSON.stringify({
                        messageId: command_2.DeviceCommand.setPetDetection.split(".")[1],
                        command: command_2.DeviceCommand.setPetDetection,
                        serialNumber: args[1],
                        value: args[2] === "true" ? true : false,
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_2.DeviceCommand.setRTSPStream:
                if (args.length === 3 && isTrueFalse(args[2])) {
                    socket.send(JSON.stringify({
                        messageId: command_2.DeviceCommand.setRTSPStream.split(".")[1],
                        command: command_2.DeviceCommand.setRTSPStream,
                        serialNumber: args[1],
                        value: args[2] === "true" ? true : false,
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_2.DeviceCommand.setAntiTheftDetection:
                if (args.length === 3 && isTrueFalse(args[2])) {
                    socket.send(JSON.stringify({
                        messageId: command_2.DeviceCommand.setAntiTheftDetection.split(".")[1],
                        command: command_2.DeviceCommand.setAntiTheftDetection,
                        serialNumber: args[1],
                        value: args[2] === "true" ? true : false,
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_2.DeviceCommand.enableDevice:
                if (args.length === 3 && isTrueFalse(args[2])) {
                    socket.send(JSON.stringify({
                        messageId: command_2.DeviceCommand.enableDevice.split(".")[1],
                        command: command_2.DeviceCommand.enableDevice,
                        serialNumber: args[1],
                        value: args[2] === "true" ? true : false,
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_2.DeviceCommand.lockDevice:
                if (args.length === 3 && isTrueFalse(args[2])) {
                    socket.send(JSON.stringify({
                        messageId: command_2.DeviceCommand.lockDevice.split(".")[1],
                        command: command_2.DeviceCommand.lockDevice,
                        serialNumber: args[1],
                        value: args[2] === "true" ? true : false,
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_2.DeviceCommand.setWatermark:
                if (args.length === 3 && isNumber(args[2])) {
                    socket.send(JSON.stringify({
                        messageId: command_2.DeviceCommand.setWatermark.split(".")[1],
                        command: command_2.DeviceCommand.setWatermark,
                        serialNumber: args[1],
                        value: Number.parseInt(args[2]),
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_2.DeviceCommand.getPropertiesMetadata:
                if (args.length === 2) {
                    socket.send(JSON.stringify({
                        messageId: command_2.DeviceCommand.getPropertiesMetadata.split(".")[1],
                        command: command_2.DeviceCommand.getPropertiesMetadata,
                        serialNumber: args[1],
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_2.DeviceCommand.getProperties:
                if (args.length === 2) {
                    socket.send(JSON.stringify({
                        messageId: command_2.DeviceCommand.getProperties.split(".")[1],
                        command: command_2.DeviceCommand.getProperties,
                        serialNumber: args[1],
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_2.DeviceCommand.setProperty:
                if (args.length === 4) {
                    socket.send(JSON.stringify({
                        messageId: command_2.DeviceCommand.setProperty.split(".")[1],
                        command: command_2.DeviceCommand.setProperty,
                        serialNumber: args[1],
                        name: args[2],
                        value: args[3],
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_2.DeviceCommand.startLivestream:
                if (args.length === 2) {
                    socket.send(JSON.stringify({
                        messageId: command_2.DeviceCommand.startLivestream.split(".")[1],
                        command: command_2.DeviceCommand.startLivestream,
                        serialNumber: args[1],
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_2.DeviceCommand.stopLivestream:
                if (args.length === 2) {
                    socket.send(JSON.stringify({
                        messageId: command_2.DeviceCommand.stopLivestream.split(".")[1],
                        command: command_2.DeviceCommand.stopLivestream,
                        serialNumber: args[1],
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_2.DeviceCommand.isLiveStreaming:
                if (args.length === 2) {
                    socket.send(JSON.stringify({
                        messageId: command_2.DeviceCommand.isLiveStreaming.split(".")[1],
                        command: command_2.DeviceCommand.isLiveStreaming,
                        serialNumber: args[1],
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_2.DeviceCommand.triggerAlarm:
                if (args.length === 3) {
                    socket.send(JSON.stringify({
                        messageId: command_2.DeviceCommand.triggerAlarm.split(".")[1],
                        command: command_2.DeviceCommand.triggerAlarm,
                        serialNumber: args[1],
                        seconds: Number.parseInt(args[2]),
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_2.DeviceCommand.panAndTilt:
                if (args.length === 3) {
                    socket.send(JSON.stringify({
                        messageId: command_2.DeviceCommand.panAndTilt.split(".")[1],
                        command: command_2.DeviceCommand.panAndTilt,
                        serialNumber: args[1],
                        direction: Number.parseInt(args[2]),
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_2.DeviceCommand.quickResponse:
                if (args.length === 3) {
                    socket.send(JSON.stringify({
                        messageId: command_2.DeviceCommand.quickResponse.split(".")[1],
                        command: command_2.DeviceCommand.quickResponse,
                        serialNumber: args[1],
                        voiceId: Number.parseInt(args[2]),
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_2.DeviceCommand.resetAlarm:
                if (args.length === 2) {
                    socket.send(JSON.stringify({
                        messageId: command_2.DeviceCommand.resetAlarm.split(".")[1],
                        command: command_2.DeviceCommand.resetAlarm,
                        serialNumber: args[1],
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_2.DeviceCommand.getVoices:
                if (args.length === 2) {
                    socket.send(JSON.stringify({
                        messageId: command_2.DeviceCommand.getVoices.split(".")[1],
                        command: command_2.DeviceCommand.getVoices,
                        serialNumber: args[1],
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_2.DeviceCommand.startDownload:
                if (args.length === 4) {
                    socket.send(JSON.stringify({
                        messageId: command_2.DeviceCommand.startDownload.split(".")[1],
                        command: command_2.DeviceCommand.startDownload,
                        serialNumber: args[1],
                        path: args[2],
                        cipherId: Number.parseInt(args[3]),
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_2.DeviceCommand.cancelDownload:
                if (args.length === 2) {
                    socket.send(JSON.stringify({
                        messageId: command_2.DeviceCommand.cancelDownload.split(".")[1],
                        command: command_2.DeviceCommand.cancelDownload,
                        serialNumber: args[1],
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_2.DeviceCommand.hasProperty:
                if (args.length === 3) {
                    socket.send(JSON.stringify({
                        messageId: command_2.DeviceCommand.hasProperty.split(".")[1],
                        command: command_2.DeviceCommand.hasProperty,
                        serialNumber: args[1],
                        propertyName: args[2],
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_2.DeviceCommand.getCommands:
                if (args.length === 2) {
                    socket.send(JSON.stringify({
                        messageId: command_2.DeviceCommand.getCommands.split(".")[1],
                        command: command_2.DeviceCommand.getCommands,
                        serialNumber: args[1],
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_2.DeviceCommand.hasCommand:
                if (args.length === 3) {
                    socket.send(JSON.stringify({
                        messageId: command_2.DeviceCommand.hasCommand.split(".")[1],
                        command: command_2.DeviceCommand.hasCommand,
                        serialNumber: args[1],
                        commandName: args[2],
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_2.DeviceCommand.startRTSPLivestream:
                if (args.length === 2) {
                    socket.send(JSON.stringify({
                        messageId: command_2.DeviceCommand.startRTSPLivestream.split(".")[1],
                        command: command_2.DeviceCommand.startRTSPLivestream,
                        serialNumber: args[1],
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_2.DeviceCommand.stopRTSPLivestream:
                if (args.length === 2) {
                    socket.send(JSON.stringify({
                        messageId: command_2.DeviceCommand.stopRTSPLivestream.split(".")[1],
                        command: command_2.DeviceCommand.stopRTSPLivestream,
                        serialNumber: args[1],
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_2.DeviceCommand.isRTSPLiveStreaming:
                if (args.length === 2) {
                    socket.send(JSON.stringify({
                        messageId: command_2.DeviceCommand.isRTSPLiveStreaming.split(".")[1],
                        command: command_2.DeviceCommand.isRTSPLiveStreaming,
                        serialNumber: args[1],
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_3.StationCommand.setGuardMode:
                if (args.length === 3 && isNumber(args[2])) {
                    socket.send(JSON.stringify({
                        messageId: command_3.StationCommand.setGuardMode.split(".")[1],
                        command: command_3.StationCommand.setGuardMode,
                        serialNumber: args[1],
                        mode: Number.parseInt(args[2]),
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_3.StationCommand.reboot:
                if (args.length === 2) {
                    socket.send(JSON.stringify({
                        messageId: command_3.StationCommand.reboot.split(".")[1],
                        command: command_3.StationCommand.reboot,
                        serialNumber: args[1],
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_3.StationCommand.isConnected:
                if (args.length === 2) {
                    socket.send(JSON.stringify({
                        messageId: command_3.StationCommand.isConnected.split(".")[1],
                        command: command_3.StationCommand.isConnected,
                        serialNumber: args[1],
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_3.StationCommand.connect:
                if (args.length === 2) {
                    socket.send(JSON.stringify({
                        messageId: command_3.StationCommand.connect.split(".")[1],
                        command: command_3.StationCommand.connect,
                        serialNumber: args[1],
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_3.StationCommand.disconnect:
                if (args.length === 2) {
                    socket.send(JSON.stringify({
                        messageId: command_3.StationCommand.disconnect.split(".")[1],
                        command: command_3.StationCommand.disconnect,
                        serialNumber: args[1],
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_3.StationCommand.getPropertiesMetadata:
                if (args.length === 2) {
                    socket.send(JSON.stringify({
                        messageId: command_3.StationCommand.getPropertiesMetadata.split(".")[1],
                        command: command_3.StationCommand.getPropertiesMetadata,
                        serialNumber: args[1],
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_3.StationCommand.getProperties:
                if (args.length === 2) {
                    socket.send(JSON.stringify({
                        messageId: command_3.StationCommand.getProperties.split(".")[1],
                        command: command_3.StationCommand.getProperties,
                        serialNumber: args[1],
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_3.StationCommand.setProperty:
                if (args.length === 4) {
                    socket.send(JSON.stringify({
                        messageId: command_3.StationCommand.setProperty.split(".")[1],
                        command: command_3.StationCommand.setProperty,
                        serialNumber: args[1],
                        name: args[2],
                        value: args[3],
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_3.StationCommand.triggerAlarm:
                if (args.length === 3) {
                    socket.send(JSON.stringify({
                        messageId: command_3.StationCommand.triggerAlarm.split(".")[1],
                        command: command_3.StationCommand.triggerAlarm,
                        serialNumber: args[1],
                        seconds: Number.parseInt(args[2]),
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_3.StationCommand.resetAlarm:
                if (args.length === 2) {
                    socket.send(JSON.stringify({
                        messageId: command_3.StationCommand.resetAlarm.split(".")[1],
                        command: command_3.StationCommand.resetAlarm,
                        serialNumber: args[1],
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_3.StationCommand.getCommands:
                if (args.length === 2) {
                    socket.send(JSON.stringify({
                        messageId: command_3.StationCommand.getCommands.split(".")[1],
                        command: command_3.StationCommand.getCommands,
                        serialNumber: args[1],
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_3.StationCommand.hasProperty:
                if (args.length === 3) {
                    socket.send(JSON.stringify({
                        messageId: command_3.StationCommand.hasProperty.split(".")[1],
                        command: command_3.StationCommand.hasProperty,
                        serialNumber: args[1],
                        propertyName: args[2],
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            case command_3.StationCommand.hasCommand:
                if (args.length === 3) {
                    socket.send(JSON.stringify({
                        messageId: command_3.StationCommand.hasCommand.split(".")[1],
                        command: command_3.StationCommand.hasCommand,
                        serialNumber: args[1],
                        commandName: args[2],
                    }));
                }
                else {
                    cmdHelp(args[0]);
                }
                break;
            /*case StationCommand.getCameraInfo:
            case StationCommand.getStorageInfo:
                console.log("Command not implemented.");
                break;*/
        }
    } while (cmd !== "quit" && cmd !== "exit");
    handleShutdown();
})();
//# sourceMappingURL=client.js.map