"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LivestreamNotRunningError = exports.LivestreamAlreadyRunningError = exports.SchemaIncompatibleError = exports.UnknownCommandError = exports.UnknownError = exports.BaseError = exports.ErrorCode = void 0;
var ErrorCode;
(function (ErrorCode) {
    ErrorCode["unknownError"] = "unknown_error";
    ErrorCode["unknownCommand"] = "unknown_command";
    ErrorCode["invalidCountryCode"] = "invalid_country_code";
    ErrorCode["invalidLanguageCode"] = "invalid_language_code";
    ErrorCode["stationNotFound"] = "station_not_found";
    ErrorCode["stationNotConnected"] = "station_not_connected";
    ErrorCode["deviceNotFound"] = "device_not_found";
    ErrorCode["deviceWrongStation"] = "device_wrong_station";
    ErrorCode["deviceInvalidProperty"] = "device_invalid_property";
    ErrorCode["deviceInvalidPropertyValue"] = "device_invalid_property_value";
    ErrorCode["devicePropertyNotSupported"] = "device_property_not_supported";
    ErrorCode["deviceReadOnlyProperty"] = "device_property_readonly";
    ErrorCode["deviceNotSupported"] = "device_not_supported";
    ErrorCode["deviceInvalidCommandValue"] = "device_invalid_command_value";
    ErrorCode["deviceLivestreamAlreadyRunning"] = "device_livestream_already_running";
    ErrorCode["deviceLivestreamNotRunning"] = "device_livestream_not_running";
    ErrorCode["schemaIncompatible"] = "schema_incompatible";
})(ErrorCode = exports.ErrorCode || (exports.ErrorCode = {}));
class BaseError extends Error {
}
exports.BaseError = BaseError;
class UnknownError extends BaseError {
    constructor(error) {
        super();
        this.error = error;
        this.errorCode = ErrorCode.unknownError;
    }
}
exports.UnknownError = UnknownError;
class UnknownCommandError extends BaseError {
    constructor(command) {
        super();
        this.command = command;
        this.errorCode = ErrorCode.unknownCommand;
    }
}
exports.UnknownCommandError = UnknownCommandError;
class SchemaIncompatibleError extends BaseError {
    constructor(schemaId) {
        super();
        this.schemaId = schemaId;
        this.errorCode = ErrorCode.schemaIncompatible;
    }
}
exports.SchemaIncompatibleError = SchemaIncompatibleError;
class LivestreamAlreadyRunningError extends Error {
    constructor(message) {
        super(message);
        Object.setPrototypeOf(this, new.target.prototype);
        this.name = LivestreamAlreadyRunningError.name;
    }
}
exports.LivestreamAlreadyRunningError = LivestreamAlreadyRunningError;
class LivestreamNotRunningError extends Error {
    constructor(message) {
        super(message);
        Object.setPrototypeOf(this, new.target.prototype);
        this.name = LivestreamNotRunningError.name;
    }
}
exports.LivestreamNotRunningError = LivestreamNotRunningError;
//# sourceMappingURL=error.js.map