"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EventForwarder = void 0;
const eufy_security_client_1 = require("eufy-security-client");
const state_1 = require("./station/state");
const event_1 = require("./station/event");
const state_2 = require("./device/state");
const event_2 = require("./device/event");
const event_3 = require("./driver/event");
const command_1 = require("./station/command");
const command_2 = require("./device/command");
const const_1 = require("./const");
const message_handler_1 = require("./device/message_handler");
const message_handler_2 = require("./driver/message_handler");
class EventForwarder {
    constructor(clients) {
        this.clients = clients;
    }
    start() {
        this.clients.driver.on("tfa request", () => {
            this.forwardEvent({
                source: "driver",
                event: event_3.DriverEvent.verifyCode,
            }, 0);
        });
        this.clients.driver.on("captcha request", (id, captcha) => {
            message_handler_2.DriverMessageHandler.captchaId = id;
            this.forwardEvent({
                source: "driver",
                event: event_3.DriverEvent.captchaRequest,
                captchaId: id,
                captcha: captcha,
            }, 7);
        });
        this.clients.driver.on("connect", () => {
            this.clients.clients.forEach((client) => this.sendEvent(client, {
                source: "driver",
                event: event_3.DriverEvent.connected,
            }));
        });
        this.clients.driver.on("close", () => {
            this.clients.clients.forEach((client) => this.sendEvent(client, {
                source: "driver",
                event: event_3.DriverEvent.disconnected,
            }));
        });
        this.clients.driver.on("push connect", () => {
            this.clients.clients.forEach((client) => this.sendEvent(client, {
                source: "driver",
                event: event_3.DriverEvent.pushConnected,
            }));
        });
        this.clients.driver.on("push close", () => {
            this.clients.clients.forEach((client) => this.sendEvent(client, {
                source: "driver",
                event: event_3.DriverEvent.pushDisconnected,
            }));
        });
        this.clients.driver.on("mqtt connect", () => {
            this.clients.clients.forEach((client) => this.sendEvent(client, {
                source: "driver",
                event: event_3.DriverEvent.mqttConnected,
            }));
        });
        this.clients.driver.on("mqtt close", () => {
            this.clients.clients.forEach((client) => this.sendEvent(client, {
                source: "driver",
                event: event_3.DriverEvent.mqttDisconnected,
            }));
        });
        this.clients.driver.on("station added", (station) => {
            this.clients.clients.forEach((client) => this.sendEvent(client, {
                source: "station",
                event: event_1.StationEvent.stationAdded,
                station: (0, state_1.dumpStation)(station, client.schemaVersion),
            }));
            this.setupStation(station);
        });
        this.clients.driver.on("station removed", (station) => {
            this.clients.clients.forEach((client) => this.sendEvent(client, {
                source: "station",
                event: event_1.StationEvent.stationRemoved,
                station: (0, state_1.dumpStation)(station, client.schemaVersion),
            }));
        });
        this.clients.driver.on("device added", (device) => {
            this.clients.clients.forEach((client) => this.sendEvent(client, {
                source: "device",
                event: event_2.DeviceEvent.deviceAdded,
                device: (0, state_2.dumpDevice)(device, client.schemaVersion),
            }));
            this.setupDevice(device);
        });
        this.clients.driver.on("device removed", (device) => {
            this.clients.clients.forEach((client) => this.sendEvent(client, {
                source: "device",
                event: event_2.DeviceEvent.deviceRemoved,
                device: (0, state_2.dumpDevice)(device, client.schemaVersion),
            }));
        });
        this.clients.driver.getStations().forEach(station => {
            this.setupStation(station);
        });
        this.clients.driver.getDevices().forEach(device => {
            this.setupDevice(device);
        });
        this.clients.driver.on("station livestream start", (station, device, metadata, videostream, audiostream) => {
            const serialNumber = device.getSerial();
            this.clients.clients.filter((cl) => cl.receiveLivestream[serialNumber] === true && cl.isConnected)
                .forEach((client) => {
                if (client.schemaVersion >= 2) {
                    client.sendEvent({
                        source: "device",
                        event: event_2.DeviceEvent.livestreamStarted,
                        serialNumber: serialNumber
                    });
                }
            });
            videostream.on("data", (chunk) => {
                this.clients.clients.filter((cl) => cl.receiveLivestream[serialNumber] === true && cl.isConnected)
                    .forEach((client) => {
                    if (client.schemaVersion >= 2) {
                        client.sendEvent({
                            source: "device",
                            event: event_2.DeviceEvent.livestreamVideoData,
                            serialNumber: serialNumber,
                            buffer: chunk,
                            metadata: {
                                videoCodec: eufy_security_client_1.VideoCodec[metadata.videoCodec],
                                videoFPS: metadata.videoFPS,
                                videoHeight: metadata.videoHeight,
                                videoWidth: metadata.videoWidth,
                            }
                        });
                    }
                });
            });
            audiostream.on("data", (chunk) => {
                this.clients.clients.filter((cl) => cl.receiveLivestream[serialNumber] === true && cl.isConnected)
                    .forEach((client) => {
                    if (client.schemaVersion >= 2) {
                        client.sendEvent({
                            source: "device",
                            event: event_2.DeviceEvent.livestreamAudioData,
                            serialNumber: serialNumber,
                            buffer: chunk,
                            metadata: {
                                audioCodec: eufy_security_client_1.AudioCodec[metadata.audioCodec],
                            }
                        });
                    }
                });
            });
        });
        this.clients.driver.on("station livestream stop", (station, device) => {
            const serialNumber = device.getSerial();
            this.clients.clients.filter((cl) => cl.receiveLivestream[serialNumber] === true && cl.isConnected)
                .forEach((client) => {
                if (client.schemaVersion >= 2) {
                    client.sendEvent({
                        source: "device",
                        event: event_2.DeviceEvent.livestreamStopped,
                        serialNumber: serialNumber,
                    });
                }
                client.receiveLivestream[serialNumber] = false;
                message_handler_1.DeviceMessageHandler.removeStreamingDevice(station.getSerial(), client);
            });
        });
        this.clients.driver.on("station download start", (station, device, metadata, videostream, audiostream) => {
            const serialNumber = device.getSerial();
            this.clients.clients.filter((cl) => cl.receiveLivestream[serialNumber] === true && cl.isConnected)
                .forEach((client) => {
                if (client.schemaVersion >= 3) {
                    client.sendEvent({
                        source: "device",
                        event: event_2.DeviceEvent.downloadStarted,
                        serialNumber: serialNumber
                    });
                }
            });
            videostream.on("data", (chunk) => {
                this.clients.clients.filter((cl) => cl.isConnected)
                    .forEach((client) => {
                    if (client.schemaVersion >= 3) {
                        client.sendEvent({
                            source: "device",
                            event: event_2.DeviceEvent.downloadVideoData,
                            serialNumber: serialNumber,
                            buffer: chunk,
                            metadata: {
                                videoCodec: eufy_security_client_1.VideoCodec[metadata.videoCodec],
                                videoFPS: metadata.videoFPS,
                                videoHeight: metadata.videoHeight,
                                videoWidth: metadata.videoWidth,
                            }
                        });
                    }
                });
            });
            audiostream.on("data", (chunk) => {
                this.clients.clients.filter((cl) => cl.receiveLivestream[serialNumber] === true && cl.isConnected)
                    .forEach((client) => {
                    if (client.schemaVersion >= 3) {
                        client.sendEvent({
                            source: "device",
                            event: event_2.DeviceEvent.downloadAudioData,
                            serialNumber: serialNumber,
                            buffer: chunk,
                            metadata: {
                                audioCodec: eufy_security_client_1.AudioCodec[metadata.audioCodec],
                            }
                        });
                    }
                });
            });
        });
        this.clients.driver.on("station download finish", (station, device) => {
            const serialNumber = device.getSerial();
            this.clients.clients.filter((cl) => cl.isConnected)
                .forEach((client) => {
                if (client.schemaVersion >= 3) {
                    client.sendEvent({
                        source: "device",
                        event: event_2.DeviceEvent.downloadFinished,
                        serialNumber: serialNumber,
                    });
                }
            });
        });
        this.clients.driver.on("station rtsp livestream start", (station, device) => {
            const serialNumber = device.getSerial();
            this.clients.clients.filter((cl) => cl.isConnected)
                .forEach((client) => {
                if (client.schemaVersion >= 6) {
                    client.sendEvent({
                        source: "device",
                        event: event_2.DeviceEvent.rtspLivestreamStarted,
                        serialNumber: serialNumber,
                    });
                }
            });
        });
        this.clients.driver.on("station rtsp livestream stop", (station, device) => {
            const serialNumber = device.getSerial();
            this.clients.clients.filter((cl) => cl.isConnected)
                .forEach((client) => {
                if (client.schemaVersion >= 6) {
                    client.sendEvent({
                        source: "device",
                        event: event_2.DeviceEvent.rtspLivestreamStopped,
                        serialNumber: serialNumber,
                    });
                }
            });
        });
    }
    forwardEvent(data, minSchemaVersion, maxSchemaVersion = const_1.maxSchemaVersion) {
        // Forward event to all connected clients
        this.clients.clients.forEach((client) => {
            if (client.schemaVersion >= minSchemaVersion && client.schemaVersion <= maxSchemaVersion) {
                this.sendEvent(client, data);
            }
        });
    }
    sendEvent(client, data) {
        // Send event to connected client only
        if (client.receiveEvents && client.isConnected) {
            client.sendEvent(data);
        }
    }
    setupStation(station) {
        station.on("connect", () => {
            this.forwardEvent({
                source: "station",
                event: event_1.StationEvent.connected,
                serialNumber: station.getSerial()
            }, 0);
        });
        station.on("close", () => {
            this.forwardEvent({
                source: "station",
                event: event_1.StationEvent.disconnected,
                serialNumber: station.getSerial()
            }, 0);
        });
        station.on("guard mode", (station, guardMode) => {
            // Event for schemaVersion <= 2
            this.forwardEvent({
                source: "station",
                event: event_1.StationEvent.guardModeChanged,
                serialNumber: station.getSerial(),
                guardMode: guardMode,
                currentMode: station.getCurrentMode().value,
            }, 0, 2);
            // Event for schemaVersion >= 3
            this.forwardEvent({
                source: "station",
                event: event_1.StationEvent.guardModeChanged,
                serialNumber: station.getSerial(),
                guardMode: guardMode,
            }, 3);
        });
        station.on("current mode", (station, currentMode) => {
            // Event for schemaVersion <= 2
            this.forwardEvent({
                source: "station",
                event: event_1.StationEvent.guardModeChanged,
                serialNumber: station.getSerial(),
                guardMode: station.getGuardMode().value,
                currentMode: currentMode,
            }, 0, 2);
            //Event for schemaVersion >= 3
            this.forwardEvent({
                source: "station",
                event: event_1.StationEvent.currentModeChanged,
                serialNumber: station.getSerial(),
                currentMode: currentMode,
            }, 3);
        });
        station.on("alarm event", (station, alarmEvent) => {
            this.forwardEvent({
                source: "station",
                event: event_1.StationEvent.alarmEvent,
                serialNumber: station.getSerial(),
                alarmEvent: alarmEvent,
            }, 3);
        });
        // eslint-disable-next-line @typescript-eslint/no-unused-vars
        station.on("rtsp url", (station, channel, value, modified) => {
            const device = this.clients.driver.getStationDevice(station.getSerial(), channel);
            this.forwardEvent({
                source: "device",
                event: event_2.DeviceEvent.gotRtspUrl,
                serialNumber: device.getSerial(),
                rtspUrl: value,
            }, 0);
        });
        station.on("command result", (station, result) => {
            //TODO: Implement this event differently or remove the commands already implemented as properties
            if (result.channel === eufy_security_client_1.Station.CHANNEL) {
                //Station command result
                let command = undefined;
                switch (result.command_type) {
                    case eufy_security_client_1.CommandType.CMD_HUB_REBOOT:
                        command = command_1.StationCommand.reboot;
                        break;
                    case eufy_security_client_1.CommandType.CMD_SET_ARMING:
                        command = command_1.StationCommand.setGuardMode;
                        break;
                    case eufy_security_client_1.CommandType.CMD_SET_TONE_FILE:
                        command = command_1.StationCommand.triggerAlarm;
                        break;
                }
                if (command !== undefined) {
                    this.forwardEvent({
                        source: "station",
                        event: event_1.StationEvent.commandResult,
                        serialNumber: station.getSerial(),
                        command: command.split(".")[1],
                        returnCode: result.return_code,
                        returnCodeName: eufy_security_client_1.ErrorCode[result.return_code] !== undefined ? eufy_security_client_1.ErrorCode[result.return_code] : "UNKNOWN",
                    }, 0);
                }
            }
            else {
                // Device command result
                let command = undefined;
                switch (result.command_type) {
                    case eufy_security_client_1.CommandType.CMD_DEVS_SWITCH:
                        command = command_2.DeviceCommand.enableDevice;
                        break;
                    case eufy_security_client_1.CommandType.CMD_DOORLOCK_DATA_PASS_THROUGH:
                        command = command_2.DeviceCommand.lockDevice;
                        break;
                    case eufy_security_client_1.CommandType.CMD_EAS_SWITCH:
                        command = command_2.DeviceCommand.setAntiTheftDetection;
                        break;
                    case eufy_security_client_1.CommandType.CMD_IRCUT_SWITCH:
                        command = command_2.DeviceCommand.setAutoNightVision;
                        break;
                    case eufy_security_client_1.CommandType.CMD_PIR_SWITCH:
                    case eufy_security_client_1.CommandType.CMD_INDOOR_DET_SET_MOTION_DETECT_ENABLE:
                    case eufy_security_client_1.ParamType.COMMAND_MOTION_DETECTION_PACKAGE:
                        command = command_2.DeviceCommand.setMotionDetection;
                        break;
                    case eufy_security_client_1.CommandType.CMD_INDOOR_DET_SET_PET_ENABLE:
                        command = command_2.DeviceCommand.setPetDetection;
                        break;
                    case eufy_security_client_1.CommandType.CMD_NAS_SWITCH:
                        command = command_2.DeviceCommand.setRTSPStream;
                        break;
                    case eufy_security_client_1.CommandType.CMD_INDOOR_DET_SET_SOUND_DETECT_ENABLE:
                        command = command_2.DeviceCommand.setSoundDetection;
                        break;
                    case eufy_security_client_1.CommandType.CMD_DEV_LED_SWITCH:
                    case eufy_security_client_1.CommandType.CMD_INDOOR_LED_SWITCH:
                    case eufy_security_client_1.CommandType.CMD_BAT_DOORBELL_SET_LED_ENABLE:
                    case eufy_security_client_1.ParamType.COMMAND_LED_NIGHT_OPEN:
                        command = command_2.DeviceCommand.setStatusLed;
                        break;
                    case eufy_security_client_1.CommandType.CMD_SET_DEVS_OSD:
                        command = command_2.DeviceCommand.setWatermark;
                        break;
                    case eufy_security_client_1.CommandType.CMD_INDOOR_ROTATE:
                        command = command_2.DeviceCommand.panAndTilt;
                        break;
                    case eufy_security_client_1.CommandType.CMD_SET_DEVS_TONE_FILE:
                        command = command_2.DeviceCommand.triggerAlarm;
                        break;
                    case eufy_security_client_1.CommandType.CMD_DOWNLOAD_VIDEO:
                        command = command_2.DeviceCommand.startDownload;
                        break;
                    case eufy_security_client_1.CommandType.CMD_DOWNLOAD_CANCEL:
                        command = command_2.DeviceCommand.cancelDownload;
                        break;
                    case eufy_security_client_1.CommandType.CMD_START_REALTIME_MEDIA:
                    case eufy_security_client_1.ParamType.COMMAND_START_LIVESTREAM:
                        command = command_2.DeviceCommand.startLivestream;
                        break;
                    case eufy_security_client_1.CommandType.CMD_STOP_REALTIME_MEDIA:
                        command = command_2.DeviceCommand.stopLivestream;
                        break;
                    case eufy_security_client_1.CommandType.CMD_BAT_DOORBELL_QUICK_RESPONSE:
                        //case 1004: //TODO: CMD_STOP_REALTIME_MEDIA has the same number
                        command = command_2.DeviceCommand.quickResponse;
                        break;
                }
                if (command !== undefined) {
                    const device = this.clients.driver.getStationDevice(station.getSerial(), result.channel);
                    this.forwardEvent({
                        source: "device",
                        event: event_2.DeviceEvent.commandResult,
                        serialNumber: device.getSerial(),
                        command: command.split(".")[1],
                        returnCode: result.return_code,
                        returnCodeName: eufy_security_client_1.ErrorCode[result.return_code] !== undefined ? eufy_security_client_1.ErrorCode[result.return_code] : "UNKNOWN",
                    }, 0);
                }
            }
        });
        station.on("property changed", (station, name, value) => {
            this.forwardEvent({
                source: "station",
                event: event_1.StationEvent.propertyChanged,
                serialNumber: station.getSerial(),
                name: name,
                value: value.value,
                timestamp: value.timestamp
            }, 0);
        });
    }
    setupDevice(device) {
        if (device instanceof eufy_security_client_1.Camera) {
            device.on("motion detected", (device, state) => {
                this.clients.clients.forEach((client) => this.sendEvent(client, {
                    source: "device",
                    event: event_2.DeviceEvent.motionDetected,
                    serialNumber: device.getSerial(),
                    state: state,
                }));
            });
            device.on("person detected", (device, state, person) => {
                this.clients.clients.forEach((client) => this.sendEvent(client, {
                    source: "device",
                    event: event_2.DeviceEvent.personDetected,
                    serialNumber: device.getSerial(),
                    state: state,
                    person: person,
                }));
            });
        }
        if (device instanceof eufy_security_client_1.IndoorCamera) {
            device.on("crying detected", (device, state) => {
                this.clients.clients.forEach((client) => this.sendEvent(client, {
                    source: "device",
                    event: event_2.DeviceEvent.cryingDetected,
                    serialNumber: device.getSerial(),
                    state: state
                }));
            });
            device.on("pet detected", (device, state) => {
                this.clients.clients.forEach((client) => this.sendEvent(client, {
                    source: "device",
                    event: event_2.DeviceEvent.petDetected,
                    serialNumber: device.getSerial(),
                    state: state,
                }));
            });
            device.on("sound detected", (device, state) => {
                this.clients.clients.forEach((client) => this.sendEvent(client, {
                    source: "device",
                    event: event_2.DeviceEvent.soundDetected,
                    serialNumber: device.getSerial(),
                    state: state,
                }));
            });
        }
        if (device instanceof eufy_security_client_1.DoorbellCamera) {
            device.on("rings", (device, state) => {
                this.clients.clients.forEach((client) => this.sendEvent(client, {
                    source: "device",
                    event: event_2.DeviceEvent.rings,
                    serialNumber: device.getSerial(),
                    state: state,
                }));
            });
        }
        if (device instanceof eufy_security_client_1.EntrySensor) {
            device.on("open", (device, state) => {
                this.clients.clients.forEach((client) => this.sendEvent(client, {
                    source: "device",
                    event: event_2.DeviceEvent.sensorOpen,
                    serialNumber: device.getSerial(),
                    state: state,
                }));
            });
        }
        if (device instanceof eufy_security_client_1.MotionSensor) {
            device.on("motion detected", (device, state) => {
                this.clients.clients.forEach((client) => this.sendEvent(client, {
                    source: "device",
                    event: event_2.DeviceEvent.motionDetected,
                    serialNumber: device.getSerial(),
                    state: state,
                }));
            });
        }
        device.on("property changed", (device, name, value) => {
            this.forwardEvent({
                source: "device",
                event: event_2.DeviceEvent.propertyChanged,
                serialNumber: device.getSerial(),
                name: name,
                value: value.value,
                timestamp: value.timestamp
            }, 0);
        });
    }
}
exports.EventForwarder = EventForwarder;
//# sourceMappingURL=forward.js.map