"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LoggingEventForwarder = void 0;
const event_1 = require("./driver/event");
class LoggingEventForwarder {
    constructor(clients, logger) {
        this.logger = logger;
        this.clients = clients;
    }
    get started() {
        return this.transport !== undefined;
    }
    start() {
        const level = this.logger.settings.minLevel;
        this.logger.info("Starting logging event forwarder at " + level + " level");
        this.transport = {
            transportLogger: {
                silly: (message) => { this.logToTransport(this.clients.clients, message); },
                debug: (message) => { this.logToTransport(this.clients.clients, message); },
                trace: (message) => { this.logToTransport(this.clients.clients, message); },
                info: (message) => { this.logToTransport(this.clients.clients, message); },
                warn: (message) => { this.logToTransport(this.clients.clients, message); },
                error: (message) => { this.logToTransport(this.clients.clients, message); },
                fatal: (message) => { this.logToTransport(this.clients.clients, message); },
            },
            minLevel: level
        };
        this.logger.attachTransport(this.transport.transportLogger, this.transport.minLevel);
    }
    stop() {
        this.logger.info("Stopping logging event forwarder");
        this.logger.setSettings({
            attachedTransports: []
        });
        delete this.transport;
    }
    restartIfNeeded() {
        var _a;
        const level = this.logger.settings.minLevel;
        if (this.started && ((_a = this.transport) === null || _a === void 0 ? void 0 : _a.minLevel) != level) {
            this.stop();
            this.start();
        }
    }
    logToTransport(clients, logObject) {
        // Forwarding logs to clients that are currently
        // receiving logs
        clients
            .filter((cl) => cl.receiveLogs && cl.isConnected)
            .forEach((client) => client.sendEvent({
            source: "driver",
            event: event_1.DriverEvent.logging,
            message: {
                ...logObject
            },
        }));
    }
}
exports.LoggingEventForwarder = LoggingEventForwarder;
//# sourceMappingURL=logging.js.map