"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StationMessageHandler = void 0;
const error_1 = require("../error");
const command_1 = require("./command");
class StationMessageHandler {
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    static async handle(message, driver, client) {
        const { serialNumber, command } = message;
        const station = driver.getStation(serialNumber);
        switch (command) {
            case command_1.StationCommand.reboot:
                await station.rebootHUB().catch((error) => {
                    throw error;
                });
                return {};
            case command_1.StationCommand.setGuardMode:
                await station.setGuardMode(message.mode).catch((error) => {
                    throw error;
                });
                return {};
            case command_1.StationCommand.isConnected:
                {
                    const result = station.isConnected();
                    if (client.schemaVersion <= 3) {
                        return { connected: result };
                    }
                    else if (client.schemaVersion >= 4) {
                        return {
                            serialNumber: station.getSerial(),
                            connected: result
                        };
                    }
                }
            case command_1.StationCommand.isConnectedLegacy:
                {
                    const result = station.isConnected();
                    return { connected: result };
                }
            /*case StationCommand.getCameraInfo:
                await station.getCameraInfo().catch((error) => {
                    throw error;
                });
                return { };
            case StationCommand.getStorageInfo:
                await station.getStorageInfo().catch((error) => {
                    throw error;
                });
                return { };*/
            case command_1.StationCommand.connect:
                await station.connect().catch((error) => {
                    throw error;
                });
                return {};
            case command_1.StationCommand.disconnect:
                station.close();
                return {};
            case command_1.StationCommand.getPropertiesMetadata:
                {
                    const properties = station.getPropertiesMetadata();
                    if (client.schemaVersion <= 3) {
                        return { properties: properties };
                    }
                    else if (client.schemaVersion >= 4) {
                        return {
                            serialNumber: station.getSerial(),
                            properties: properties
                        };
                    }
                }
            case command_1.StationCommand.getProperties:
                {
                    const properties = station.getProperties();
                    if (client.schemaVersion <= 3) {
                        return { properties: properties };
                    }
                    else if (client.schemaVersion >= 4) {
                        return {
                            serialNumber: station.getSerial(),
                            properties: properties
                        };
                    }
                }
            case command_1.StationCommand.setProperty:
                await driver.setStationProperty(serialNumber, message.name, message.value).catch((error) => {
                    throw error;
                });
                return {};
            case command_1.StationCommand.triggerAlarm:
                if (client.schemaVersion >= 3) {
                    await station.triggerStationAlarmSound(message.seconds).catch((error) => {
                        throw error;
                    });
                    return {};
                }
            case command_1.StationCommand.resetAlarm:
                if (client.schemaVersion >= 3) {
                    await station.resetStationAlarmSound().catch((error) => {
                        throw error;
                    });
                    return {};
                }
            case command_1.StationCommand.hasProperty:
                {
                    if (client.schemaVersion >= 3) {
                        const result = station.hasProperty(message.propertyName);
                        if (client.schemaVersion === 3) {
                            return { exists: result };
                        }
                        else if (client.schemaVersion >= 4) {
                            return {
                                serialNumber: station.getSerial(),
                                exists: result
                            };
                        }
                    }
                }
            case command_1.StationCommand.hasCommand:
                {
                    if (client.schemaVersion >= 3) {
                        const result = station.hasCommand(message.commandName);
                        if (client.schemaVersion === 3) {
                            return { exists: result };
                        }
                        else if (client.schemaVersion >= 4) {
                            return {
                                serialNumber: station.getSerial(),
                                exists: result
                            };
                        }
                    }
                }
            case command_1.StationCommand.getCommands:
                {
                    if (client.schemaVersion >= 3) {
                        const result = station.getCommands();
                        if (client.schemaVersion === 3) {
                            return { commands: result };
                        }
                        else if (client.schemaVersion >= 4) {
                            return {
                                serialNumber: station.getSerial(),
                                commands: result
                            };
                        }
                    }
                }
            default:
                throw new error_1.UnknownCommandError(command);
        }
    }
}
exports.StationMessageHandler = StationMessageHandler;
//# sourceMappingURL=message_handler.js.map